==> koffice-trinity-3.5.13.2.tar.xz: koffice-trinity-3.5.13.2/kugar/kudesigner/kudesigner_factory.h <==
/* This file is part of the KDE project
  Copyright (C) 2002 Alexander Dymo <cloudtemple@mksat.net>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to
  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KUDESIGNER_FACTORY_H
#define KUDESIGNER_FACTORY_H

#include <KoFactory.h>
#include <koffice_export.h>
class KInstance;
class KAboutData;

class KUGARDESIGNER_EXPORT KudesignerFactory : public KoFactory
{
    Q_OBJECT
  TQ_OBJECT
public:
    KudesignerFactory( TQObject* parent = 0, const char* name = 0 );
    ~KudesignerFactory();

    virtual KParts::Part *createPartObject( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0, const char *classname = "KoDocument", const TQStringList &args = TQStringList() );

    static KInstance* global();

    // _Creates_ a KAboutData but doesn't keep ownership
    static KAboutData* aboutData();

private:
    static KInstance* s_global;
    static KAboutData* s_aboutData;
};

#endif

==> koffice-trinity_14.1.0.orig.tar.xz: koffice-trinity-14.1.0/kugar/kudesigner/kudesigner_factory.h <==
/* This file is part of the KDE project
  Copyright (C) 2002 Alexander Dymo <cloudtemple@mksat.net>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to
  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KUDESIGNER_FACTORY_H
#define KUDESIGNER_FACTORY_H

#include <KoFactory.h>
#include <koffice_export.h>
class TDEInstance;
class TDEAboutData;

class KUGARDESIGNER_EXPORT KudesignerFactory : public KoFactory
{
    Q_OBJECT
  
public:
    KudesignerFactory( TQObject* parent = 0, const char* name = 0 );
    ~KudesignerFactory();

    virtual KParts::Part *createPartObject( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0, const char *classname = "KoDocument", const TQStringList &args = TQStringList() );

    static TDEInstance* global();

    // _Creates_ a TDEAboutData but doesn't keep ownership
    static TDEAboutData* aboutData();

private:
    static TDEInstance* s_global;
    static TDEAboutData* s_aboutData;
};

#endif
